CountdownController class

Inheritance

Constructors

CountdownController({int? timestamp, Duration? duration, Duration stepDuration = const Duration(milliseconds: 1000), VoidCallback? onEnd})

Properties

currentDuration → Duration
no setter
currentRemainingTime → CurrentRemainingTime
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isRunning → bool
no setter
onEnd → VoidCallback?
Event called after the countdown ends
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepDuration → Duration
final
value ↔ int
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
start() → dynamic
start
stop() → dynamic
pause
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited