CurrentRemainingTime class

Constructors

CurrentRemainingTime({int? days, int? hours, int? min, int? sec, Animation<double>? milliseconds})

Properties

days → int?
final
hashCode → int
The hash code for this object.
no setterinherited
hours → int?
final
milliseconds → Animation<double>?
final
min → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sec → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited